SemanticClass

Enum SemanticClass 

pub enum SemanticClass {
Show 55 variants Conjunction, Disjunction, Negation, Implication, Biconditional, ExclusiveOr, Verum, Falsum, Necessity, Possibility, Knows, Believes, CommonKnowledge, DistributedKnowledge, Obligatory, Permitted, Forbidden, Waived, Globally, Finally, Next, Until, Release, WeakUntil, MembershipDegree, FuzzyAnd, FuzzyOr, Probability, BothTrueAndFalse, NeitherTrueNorFalse, Universal, Existential, UniqueExistential, ElementOf, NotElementOf, Subset, StrictSubset, Union, Intersection, EmptySet, Equals, NotEquals, LessThan, LessOrEqual, GreaterThan, GreaterOrEqual, Turnstile, DoubleTurnstile, Therefore, Because, Identifier, NumericLiteral, StringLiteral, BooleanLiteral, TimeLiteral,
}
The semantic role of a symbol within its logic paradigm(s).

Variants



Conjunction



Disjunction



Negation



Implication



Biconditional



ExclusiveOr



Verum



Falsum



Necessity



Possibility



Knows



Believes



CommonKnowledge



DistributedKnowledge



Obligatory



Permitted



Forbidden



Waived



Globally



Finally



Next



Until



Release



WeakUntil



MembershipDegree



FuzzyAnd



FuzzyOr



Probability



BothTrueAndFalse



NeitherTrueNorFalse



Universal



Existential



UniqueExistential



ElementOf



NotElementOf



Subset



StrictSubset



Union



Intersection



EmptySet



Equals



NotEquals



LessThan



LessOrEqual



GreaterThan



GreaterOrEqual



Turnstile



DoubleTurnstile



Therefore



Because



Identifier



NumericLiteral



StringLiteral



BooleanLiteral



TimeLiteral

Implementations

Source

impl SemanticClass

pub fn paradigms(self) -> &'static [Paradigm]

The set of paradigms this operator contributes to. A single symbol can participate in multiple paradigms.